@@ -1,5 +1,8 @@
 from .jusbr_pomes import (
-    jusbr_setup, jusbr_get_token, jusbr_set_scope
+    jusbr_setup, jusbr_get_token
+)
+from .keycloak_pomes import (
+    keycloak_setup, keycloak_get_token
 )
 from .provider_pomes import (
     provider_register, provider_get_token
@@ -10,7 +13,9 @@ from .token_pomes import (
 
 __all__ = [
     # jusbr_pomes
-    "jusbr_setup", "jusbr_get_token", "jusbr_set_scope",
+    "jusbr_setup", "jusbr_get_token",
+    # keycloak_pomes
+    "keycloak_setup", "keycloak_get_token",
     # provider_pomes
     "provider_register", "provider_get_token",
     # token_pomes
